// -----------------------------------------------------------------------
// <copyright file="Address.cs" company="Imar.Spaanjaars.Com">
//   Copyright 2008 - 2009 - Imar.Spaanjaars.Com. All rights reserved.
// </copyright>
// -----------------------------------------------------------------------

using System;
using System.ComponentModel;
using System.Diagnostics;
using Spaanjaars.Validation;

namespace Spaanjaars.ContactManager.BusinessEntities
{
	/// <summary>
	/// The Address class represents an address that belongs to a <see cref="ContactPerson">contact person</see>.
	/// </summary>
	[DebuggerDisplay("Address: {Street, nq} {HouseNumber, nq} {City, nq} - {Country, nq} ({Type, nq})")]
	public class Address : BusinessBase
	{
		#region Constructor(s)

		/// <summary>
		/// Initializes a new instance of the Address class.
		/// </summary>
		public Address()
		{
			Type = ContactType.None;
		}

		#endregion

		#region Public Properties

		/// <summary>
		/// Gets or sets the unique ID of the address.
		/// </summary>
		[DataObjectFieldAttribute(true, true, false)]
		public override int Id { get; set; }

		/// <summary>
		/// Gets or sets the Street of the address.
		/// </summary>
		[NotNullOrEmpty(Key = "StreetNotEmpty")]
		public string Street { get; set; }

		/// <summary>
		/// Gets or sets the HouseNumber of the address.
		/// </summary>
		[NotNullOrEmpty(Key = "HouseNumberNotEmpty")]
		public string HouseNumber { get; set; }

		/// <summary>
		/// Gets or sets the ZipCode of the address.
		/// </summary>
		[NotNullOrEmpty(Key = "ZipCodeNotEmpty")]
		public string ZipCode { get; set; }

		/// <summary>
		/// Gets or sets the City of the address.
		/// </summary>
		[NotNullOrEmpty(Key = "CityNotEmpty")]
		public string City { get; set; }

		/// <summary>
		/// Gets or sets the Country of the address.
		/// </summary>
		[NotNullOrEmpty(Key = "CountryNotEmpty")]
		public string Country { get; set; }

		/// <summary>
		/// Gets or sets the type of the address, like business or personal.
		/// </summary>
		[EnumNotNoneAttribute(Key = "ContactTypeNotNone")]
		public ContactType Type { get; set; }

		/// <summary>
		/// Gets or sets the ID of the owner (a <see cref="ContactPerson"/>) of the address.
		/// </summary>
		public int ContactPersonId { get; set; }

		#endregion
	}
}