// -----------------------------------------------------------------------
// <copyright file="PagingTests.cs" company="Imar.Spaanjaars.Com">
//   Copyright 2008 - 2009 - Imar.Spaanjaars.Com. All rights reserved.
// </copyright>
// -----------------------------------------------------------------------

using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Spaanjaars.ContactManager.BusinessEntities;
using Spaanjaars.ContactManager.Bll;
using System.Threading;
using System.Security.Principal;

namespace Spaanjaars.Validation.Tests
{
	/// <summary>
	/// Summary description for PagingTests
	/// </summary>
	[TestClass]
	public class PagingTests
	{
		[TestMethod]
		public void PagingContactPeople()
		{
			ContactPersonCollection myList = ContactPersonManager.GetList();

			// Make sure we look like an Administrator before we call this code.
			GenericIdentity myIdentity = new GenericIdentity("Admin");
			Thread.CurrentPrincipal = new GenericPrincipal(myIdentity, new string[] { "Administrators" });

			foreach (ContactPerson myContactPerson in myList)
			{
				ContactPersonManager.Delete(myContactPerson);
			}

			for (int i = 1; i <= 100; i++)
			{
				ContactPerson myPerson = new ContactPerson();
				myPerson.DateOfBirth = DateTime.Now;
				myPerson.FirstName = string.Format("First {0}", i.ToString().PadLeft(3, '0'));
				myPerson.LastName = string.Format("Last {0}", i.ToString().PadLeft(3, '0'));
				myPerson.Type = PersonType.Colleague;
				ContactPersonManager.Save(myPerson);
			}

			myList = ContactPersonManager.GetList();

			Assert.AreEqual(100, myList.Count);

			// Now we have a valid working set, let's do some paging.
			// Get the first 10 records on the first page.
			myList = ContactPersonManager.GetList("FirstName", 0, 10);
			Assert.AreEqual(10, myList.Count);
			for (int i = 1; i <= 10; i++)
			{
				Assert.AreEqual(string.Format("First {0}", i.ToString().PadLeft(3, '0')), myList[i - 1].FirstName);
			}

			// Get a page with 20 records
			myList = ContactPersonManager.GetList("FirstName", 30, 20);
			Assert.AreEqual(20, myList.Count);
			for (int i = 1; i <= 10; i++)
			{
				Assert.AreEqual(string.Format("First {0}", (i + 30).ToString().PadLeft(3, '0')), myList[i - 1].FirstName);
			}

			// Get non existing data
			myList = ContactPersonManager.GetList("FirstName", 200, 20);
			Assert.AreEqual(0, myList.Count);
		}

		//[TestMethod] // disabled, requires MSDTC
		//public void PageEmailAddresses()
		//{
		//  ContactPerson myContactPerson = Helpers.CreateContactPerson();
		//  for (int i = 0; i < 100; i++)
		//  {
		//    EmailAddress myEmailAddress = new EmailAddress();
		//    myEmailAddress.Email = i.ToString() + "@spaanjaars.com";
		//    myEmailAddress.Type = ContactType.Business;
		//    myContactPerson.EmailAddresses.Add(myEmailAddress);
		//  }
		//  ContactPersonManager.Save(myContactPerson);
		//}
	}
}
